#!/usr/bin/env python3

from tkinter import Tk, Label, Button, Frame
from PIL import ImageTk,Image
from pkg_resources import resource_filename
from .version import VERSION
from .database import Csv


_DEFAULT_COLOR = "#d9d9d9"
_AZURE_COLOR = "#5795f9"
_BLUE_COLOR = "#144593"
_GREEN_COLOR = "#66ce54"
_YELLOW_COLOR = "#f9ef31"
_PURPLE_COLOR = "#8757f9"
_RED_COLOR = "#ff4f4f"

PIECES = {}
SPECIES = {}
CLASSES = {}

SPECIES_DESCRIPTION_1 = None
SPECIES_NUMBER_1 = None

SPECIES_DESCRIPTION_2 = None
SPECIES_NUMBER_2 = None

CLASS_DESCRIPTION = None
CLASS_NUMBER = None

SKILL_DESCRIPTION = None

BUTTONS = {}

def reset_all_buttons():
    global BUTTONS

    for key, value in BUTTONS.items():
        value[0].config(bg = _DEFAULT_COLOR)


def highlight_similarity(piece_name, index, first_color, second_color):
    global PIECES
    global _PURPLE_COLOR

    similarity_list = PIECES[piece_name][index].split('/')

    for key, value in BUTTONS.items():
        check_similarity_list = PIECES[key][index].split('/')

        if key != piece_name:
            color = _DEFAULT_COLOR

        if similarity_list[0] in check_similarity_list:
            color = first_color
        elif 1 < len(similarity_list) \
             and similarity_list[1] in check_similarity_list:
            color = second_color

        if value[0].cget("bg") == _DEFAULT_COLOR:
            value[0].config(bg = color)
        elif color != _DEFAULT_COLOR:
            value[0].config(bg = _PURPLE_COLOR)


def highlight_species(piece_name):
    global _AZURE_COLOR
    global _BLUE_COLOR
    global _GREEN_COLOR
    global _YELLOW_COLOR

    highlight_similarity(piece_name, 0, _GREEN_COLOR, _YELLOW_COLOR)

    highlight_similarity(piece_name, 1, _AZURE_COLOR, _BLUE_COLOR)


def button_click(piece_name):
    global BUTTONS
    global SPECIES_DESCRIPTION_1
    global SPECIES_NUMBER_1
    global SPECIES_DESCRIPTION_2
    global SPECIES_NUMBER_2
    global CLASS_DESCRIPTION
    global CLASS_NUMBER
    global SKILL_DESCRIPTION
    global PIECES
    global SPECIES
    global CLASSES
    global _RED_COLOR

    reset_all_buttons()

    BUTTONS[piece_name][0].config(bg = _RED_COLOR)

    highlight_species(piece_name)

    species = PIECES[piece_name][0].split('/')
    SPECIES_NUMBER_1.config(text = SPECIES[species[0]][0])
    SPECIES_DESCRIPTION_1.config(text = SPECIES[species[0]][1])

    if 1 < len(species):
        SPECIES_NUMBER_2.config(text = SPECIES[species[1]][0])
        SPECIES_DESCRIPTION_2.config(text = SPECIES[species[1]][1])
    else:
        SPECIES_NUMBER_2.config(text = "")
        SPECIES_DESCRIPTION_2.config(text = "")

    if PIECES[piece_name][1] in CLASSES.keys():
        CLASS_NUMBER.config(text = CLASSES[PIECES[piece_name][1]][0])
        CLASS_DESCRIPTION.config(text = CLASSES[PIECES[piece_name][1]][1])

    SKILL_DESCRIPTION.config(text = PIECES[piece_name][3])


def add_button(window, button_click, piece, level, column, row):
    button = Button(window)
    button.grid(column = column, row = row)

    resource = resource_filename("dac_picker", "images/pieces/" + piece + ".png")

    img = ImageTk.PhotoImage(Image.open(resource))

    button.config(image = img, command = lambda:button_click(piece),
                  compound = "top", text = '* ' * int(level),
                  font=("Arial Bold", 5), pady = 0, padx = 0)

    return button, img


def add_buttons(window):
    global BUTTONS
    global PIECES

    row = 0
    column = 0

    for key, value in sorted(PIECES.items()):
        BUTTONS[key] = add_button(window, button_click, key, value[2], \
                                column, row)

        column += 1

        if 10 < column:
            column = 0
            row += 1


def make_window():
    global VERSION
    global SPECIES_DESCRIPTION_1
    global SPECIES_NUMBER_1
    global SPECIES_DESCRIPTION_2
    global SPECIES_NUMBER_2
    global CLASS_DESCRIPTION
    global CLASS_NUMBER
    global SKILL_DESCRIPTION
    global _PURPLE_COLOR
    global _GREEN_COLOR
    global _YELLOW_COLOR
    global _AZURE_COLOR
    global _RED_COLOR

    window = Tk()

    window.title("Dota Auto Chess Pieces Picker " + VERSION)

    buttons_frame = Frame(height = 2, bd = 1, relief = "sunken")
    buttons_frame.pack(fill = "both", expand = True)

    add_buttons(buttons_frame)

    info_frame = Frame(height = 2, bd = 1, relief = "sunken")
    info_frame.pack(fill = "both", expand = True)


    color1 = Label(info_frame, bg = _GREEN_COLOR, width = 4, height = 1)
    color1.grid(column = 0, row = 0)

    color2 = Label(info_frame, bg = _YELLOW_COLOR, width = 4, height = 1)
    color2.grid(column = 0, row = 1)

    color3 = Label(info_frame, bg = _AZURE_COLOR, width = 4, height = 1)
    color3.grid(column = 0, row = 2)

    color4 = Label(info_frame, bg = _PURPLE_COLOR, width = 4, height = 1)
    color4.grid(column = 0, row = 3)

    color5 = Label(info_frame, bg = _RED_COLOR, width = 4, height = 1)
    color5.grid(column = 0, row = 4)


    SPECIES_NUMBER_1 = Label(info_frame, font=("Arial Bold", 12))
    SPECIES_NUMBER_1.grid(column = 1, row = 0, sticky = 'W', padx = (10, 0))

    SPECIES_NUMBER_2 = Label(info_frame, font=("Arial Bold", 12))
    SPECIES_NUMBER_2.grid(column = 1, row = 1, sticky = 'W', padx = (10, 0))

    CLASS_NUMBER = Label(info_frame, font=("Arial Bold", 12))
    CLASS_NUMBER.grid(column = 1, row = 2, sticky = 'W', padx = (10, 0))


    SPECIES_DESCRIPTION_1 = Label(info_frame, font=("Arial Bold", 12),
        wraplength=300, anchor="nw", justify="left")

    SPECIES_DESCRIPTION_1.grid(column = 2, row = 0, sticky = 'W',
        padx = (10, 0))

    SPECIES_DESCRIPTION_2 = Label(info_frame, font=("Arial Bold", 12),
        wraplength=300, anchor="nw", justify="left")

    SPECIES_DESCRIPTION_2.grid(column = 2, row = 1, sticky = 'W', padx = (10, 0))

    CLASS_DESCRIPTION = Label(info_frame, font=("Arial Bold", 12),
        wraplength=300, anchor="nw", justify="left")

    CLASS_DESCRIPTION.grid(column = 2, row = 2, sticky = 'W', padx = (10, 0))

    both_description = Label(info_frame, text = "Both species and class matches",
        font=("Arial Bold", 12), wraplength=300, anchor="nw",
        justify="left")
    both_description.grid(column = 2, row = 3, sticky = 'W', padx = (10, 0))

    SKILL_DESCRIPTION = Label(info_frame, font=("Arial Bold", 12),
        wraplength=300, anchor="nw", justify="left")
    SKILL_DESCRIPTION.grid(column = 2, row = 4, sticky = 'W', padx = (10, 0))

    window.mainloop()


def main():
    global PIECES
    global SPECIES
    global CLASSES

    PIECES = Csv.load("database/csv/pieces.csv", 4)

    SPECIES = Csv.load("database/csv/species.csv", 2)

    CLASSES = Csv.load("database/csv/classes.csv", 2)

    make_window()


if __name__ == '__main__':
  main()



#!/usr/bin/env python3
import os
import ntpath
import sys
from csv import reader
from pkg_resources import resource_filename
from shutil import copyfile

if sys.platform == "win32":
    USER_PATH = os.path.expanduser("~") + "/AppData/Local/dac_picker/"
else:
    USER_PATH = os.path.expanduser("~") + "/.local/share/dac_picker/"

def get_filename(resource):
    return USER_PATH + ntpath.basename(resource)

def copy_resource_file(resource):
    path = get_filename(resource)

    if os.path.exists(path): return

    if not os.path.exists(USER_PATH):
        os.mkdir(USER_PATH)

    copyfile(resource, path)

class Csv(object):
    @staticmethod
    def load(file, max_column):
        copy_resource_file(resource_filename("dac_picker", file))

        result = {}
        with open(get_filename(file)) as csv_file:
            csv_reader = reader(csv_file, delimiter=';')
            # Skip the columns headers
            next(csv_reader)

            for line in csv_reader:
                if max_column == 4:
                    result[line[0]] = [line[1], line[2], line[3], line[4]]
                elif max_column == 3:
                    result[line[1]] = [line[2], line[3], line[0]]
                else:
                    result[line[0]] = [line[1], line[2]]

        return result

    @staticmethod
    def load_combos(file):
        copy_resource_file(resource_filename("dac_picker", file))

        result = {}
        with open(get_filename(file)) as csv_file:
            csv_reader = reader(csv_file, delimiter=';')
            # Skip the columns headers
            next(csv_reader)

            for line in csv_reader:
                if not line[1] in result.keys():
                    result[line[1]] = []

                result[line[1]].append([line[0], line[2], line[3], line[4]])

        return result



#!/usr/bin/env python3

from tkinter import Tk, Label, Button, Frame
from PIL import ImageTk,Image
from pkg_resources import resource_filename
from .version import VERSION
from .database import Csv


_DEFAULT_COLOR = "#d9d9d9"
_AZURE_COLOR = "#5795f9"
_GREEN_COLOR = "#66ce54"
_YELLOW_COLOR = "#f9ef31"
_RED_COLOR = "#ff4f4f"

ITEMS = {}
BUTTONS = {}

ITEM_DESCRIPTION = None


def reset_all_buttons():
    global BUTTONS

    for key, value in BUTTONS.items():
      value[0].config(bg = _DEFAULT_COLOR)


def highlight_components(item_name):
    global ITEMS
    global _GREEN_COLOR
    global _YELLOW_COLOR
    global _RED_COLOR

    components = [component.strip() for component in ITEMS[item_name][1].split(',')]

    if not components:
        return

    for component in components:
        if not component:
            continue

        if BUTTONS[component][0].cget("bg") == _GREEN_COLOR:
            BUTTONS[component][0].config(bg = _YELLOW_COLOR)
        elif BUTTONS[component][0].cget("bg") != _RED_COLOR:
            BUTTONS[component][0].config(bg = _GREEN_COLOR)


def highlight_upgrades(item_name):
    global ITEMS
    global _AZURE_COLOR

    for key, value in ITEMS.items():
        if item_name in value[1] and BUTTONS[key][0].cget("bg") != _RED_COLOR:
            BUTTONS[key][0].config(bg = _AZURE_COLOR)


def button_click(item_name):
    global BUTTONS
    global ITEMS
    global ITEM_DESCRIPTION
    global _RED_COLOR

    reset_all_buttons()

    BUTTONS[item_name][0].config(bg = _RED_COLOR)

    ITEM_DESCRIPTION.config(text = ITEMS[item_name][0])

    highlight_components(item_name)

    highlight_upgrades(item_name)


def add_button(window, handler, item_name, tier, column, row):
    button = Button(window)
    button.grid(column = column, row = row)

    resource = resource_filename("dac_picker",
        "images/items/" + item_name + ".png")

    img = ImageTk.PhotoImage(Image.open(resource))
    tier_text = "* " * int(tier) if tier.isdigit() else tier

    button.config(image = img, command = lambda:handler(item_name),
        compound = "top", text = tier_text, font=("Arial Bold", 5),
        pady = 0, padx = 0)

    return button, img


def add_buttons(window):
    global BUTTONS
    global ITEMS

    row = 0
    column = 0

    for key, value in sorted(ITEMS.items()):
        BUTTONS[key] = add_button(window, button_click, key, value[2],
            column, row)

        column += 1

        if 6 < column:
            column = 0
            row += 1


def make_window():
    global VERSION
    global BUTTONS
    global ITEM_DESCRIPTION

    window = Tk()

    window.title("Dota Auto Chess Items Picker " + VERSION)

    buttons_frame = Frame(height = 2, bd = 1, relief = "sunken")
    buttons_frame.pack(fill = "both", expand = True)

    add_buttons(buttons_frame)

    info_frame = Frame(height = 2, bd = 1, relief = "sunken")
    info_frame.pack(fill = "both", expand = True)

    ITEM_DESCRIPTION = Label(info_frame, font=("Arial Bold", 12),
        wraplength=400, anchor="nw", justify="left")

    ITEM_DESCRIPTION.grid(column = 0, row = 0, sticky = 'W', padx = (30, 0))

    window.mainloop()


def main():
    global ITEMS

    ITEMS = Csv.load("database/csv/items.csv", 3)

    make_window()


if __name__ == '__main__':
  main()



#!/usr/bin/env python3
import os
from pathlib import Path
from setuptools import setup, find_packages
from dac_picker.version import VERSION

PACKAGE_DIR = Path(os.path.join(os.path.dirname(__file__), 'dac_picker'))

if __name__ == '__main__':
    setup(
        name='dac_picker',
        version=VERSION,
        packages=find_packages(),
        include_package_data=True,
        install_requires=['setuptools', 'setuptools-git', 'Pillow'],
        license='gpl-3.0',
        url='https://github.com/ellysh/dota-auto-chess-picker',
        author='Ilya Shpigor',
        author_email='petrsum@gmail.com',
        description='Set of utilities for planning your strategy in Dota Auto Chess.',
        long_description=open("README.md").read(),
        long_description_content_type='text/markdown',
        download_url = 'https://github.com/ellysh/dota-auto-chess-picker/archive/master.zip',
        keywords=['dota2', 'counter-pick'],
        entry_points={
            'console_scripts': [
                'dac-combo-picker=dac_picker.combo_picker:main',
                'dac-items-picker=dac_picker.items_picker:main',
                'dac-pieces-picker=dac_picker.pieces_picker:main',
            ],
        },
        classifiers=[
            'Development Status :: 3 - Alpha',

            'Intended Audience :: End Users/Desktop',
            'Topic :: Games/Entertainment :: Real Time Strategy',

            'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

            'Programming Language :: Python :: 3',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Programming Language :: Python :: 3.6',
          ],

    )



#!/usr/bin/env python3

from tkinter import ttk, Tk, Label, Button
from PIL import ImageTk,Image
from pkg_resources import resource_filename
from .version import VERSION
from .database import Csv


_DEFAULT_COLOR = "#d9d9d9"
_AZURE_COLOR = "#5795f9"
_GREEN_COLOR = "#66ce54"
_PURPLE_COLOR = "#8757f9"
_RED_COLOR = "#ff4f4f"

PIECES = {}
COMBOS = {}

PICKED_PIECES = set()
BUTTONS = []
WIDGETS = []


def reset_all_buttons():
    global BUTTONS
    global _DEFAULT_COLOR

    for button in BUTTONS:
        button[1].config(bg = _DEFAULT_COLOR)

def highlight_piece():
    global BUTTONS
    global _RED_COLOR
    global PICKED_PIECES

    if not PICKED_PIECES:
        return

    for button in BUTTONS:
        if button[0] in PICKED_PIECES:
            button[1].config(bg = _RED_COLOR)

def highlight_species():
    global PIECES
    global BUTTONS
    global _GREEN_COLOR
    global PICKED_PIECES

    if not PICKED_PIECES:
        return

    species = []
    for piece in PICKED_PIECES:
        species.extend(PIECES[piece][0].split('/'))

    for button in BUTTONS:
        button_species = PIECES[button[0]][0].split('/')

        if not set(species).isdisjoint(button_species):
            button[1].config(bg = _GREEN_COLOR)


def highlight_class():
    global PIECES
    global BUTTONS
    global _AZURE_COLOR
    global _PURPLE_COLOR

    if not PICKED_PIECES:
        return

    classes = []
    for piece in PICKED_PIECES:
        classes.extend(PIECES[piece][1].split('/'))

    for button in BUTTONS:
        button_classes =  PIECES[button[0]][1].split('/')

        if not set(classes).isdisjoint(button_classes):
            if button[1].cget("bg") == _DEFAULT_COLOR:
                color = _AZURE_COLOR
            else:
                color = _PURPLE_COLOR

        button[1].config(bg = color)


def add_remove_picked_piece(piece_name):
    global PICKED_PIECES

    if piece_name in PICKED_PIECES:
        PICKED_PIECES.remove(piece_name)
    else:
        PICKED_PIECES.add(piece_name)


def button_click(piece_name):
    add_remove_picked_piece(piece_name)

    reset_all_buttons()

    highlight_species()

    highlight_class()

    highlight_piece()


def add_button(window, piece, level, column, row):
    button = Button(window)
    button.grid(column = column, row = row)

    resource = resource_filename("dac_picker", "images/pieces/" + piece + ".png")

    img = ImageTk.PhotoImage(Image.open(resource))

    button.config(image = img, command = lambda:button_click(piece),
        compound = "top", text = '* ' * int(level),
        font=("Arial Bold", 5), pady = 0, padx = 0)

    return [piece, button, img]


def sort_priority(val):
    return val[0]


def add_combos(window, game_phase):
    global BUTTONS
    global PIECES
    global COMBOS

    row = 0

    combos = COMBOS[game_phase]
    combos.sort(key = sort_priority)

    for combo in combos:
        name_label = Label(window, font=("Arial Bold", 10), text = combo[1])
        name_label.grid(column = 0, row = row)

        WIDGETS.append(name_label)

        line_label = Label(window, font=("Arial Bold", 10), text = combo[2])
        line_label.grid(column = 1, row = row)

        WIDGETS.append(line_label)

        pieces = [x.strip() for x in combo[3].split(',')]

        column = 2
        for piece in pieces:
            BUTTONS.append(add_button(window, piece, PIECES[piece][2],
                column, row))

            column += 1

        row += 1


def reset_picked_pieces():
    global BUTTONS
    global PICKED_PIECES

    PICKED_PIECES = set()

    reset_all_buttons()


def make_window():
    global VERSION

    window = Tk()

    window.title("Dota Auto Chess Strategy Picker " + VERSION)

    notebook = ttk.Notebook(window)

    earlygame_page = ttk.Frame(notebook)
    notebook.add(earlygame_page, text="Earlygame")
    add_combos(earlygame_page, "Earlygame")

    midgame_page = ttk.Frame(notebook)
    notebook.add(midgame_page, text="Midgame")
    add_combos(midgame_page, "Midgame")

    lategame_page = ttk.Frame(notebook)
    notebook.add(lategame_page, text="Lategame")
    add_combos(lategame_page, "Lategame")

    notebook.pack(expand=1, fill="both")

    window.bind('<Escape>', lambda event: reset_picked_pieces())

    window.mainloop()


def main():
    global PIECES
    global COMBOS

    PIECES = Csv.load("database/csv/pieces.csv", 4)

    COMBOS = Csv.load_combos("database/csv/combos.csv")

    make_window()


if __name__ == '__main__':
  main()
